@@ -1,7 +1,7 @@
 from urllib import urlencode, quote_plus
+from datetime import datetime, date
 import urllib2
 
-
 try:
     import functools
     partial = functools.partial
@@ -88,7 +88,7 @@ class MailChimp(object):
             if type(value) in (list, dict):
                 pairs.append(self._serialize(value, name))
             elif value is not None:
-                if type(value) == bool:
+                if type(value) in (bool, datetime, date, int):
                     value = str(value).lower()
                 pairs.append('%s=%s' % (name, quote_plus(value)))
         return '&'.join(pairs)
